from marshmallow import Schema, fields
from marshmallow.validate import Length
from marshmallow import RAISE

from datetime import datetime
import uuid


class ControlConfigurationSchema(Schema):
    robot_address = fields.Str(required=True)
    program_url = fields.Str(required=True)

    class Meta:
        unknown = RAISE


class ControlStatusConfigurationSchema(Schema):
    cluster_ip = fields.IP(required=False, dump_only=True)
    running = fields.Boolean(required=False, dump_only=True)

    class Meta:
        unknown = RAISE


class ControllerSchema(Schema):
    pod_id = fields.UUID(required=False, missing=uuid.uuid4)
    configuration = fields.Nested(ControlConfigurationSchema, many=False, required=True)
    status = fields.Nested(ControlStatusConfigurationSchema, required=False, dump_only=True)

    class Meta:
        unknown = RAISE


class JobSchema(Schema):
    id = fields.UUID(required=False, missing=uuid.uuid4)
    created_at = fields.DateTime(required=False, missing=datetime.now)

    controllers = fields.Nested(ControlConfigurationSchema, many=True, required=True, validate=Length(min=1))

    class Meta:
        unknown = RAISE
